//*************************************** 
//***************************************
//   
//  AVRLIB-DEMO
//  For avrlib and avrmini development board.
//  
//
//  File:     fourbutton.c
//  Author:   Michael Gurevich
//  Date:     Sept. 22, 2002
//  Modified: Sept: 22, 2002
//  
//
//  Using the avrmini development board, connect
//  the LED/pushbutton jumper to the Port D jumper.
//  
//
//***************************************
// This program causes each of the LEDs
// on the avrmini to light when its
// corresponding button is pressed.
//
//***************************************


#include <io.h>
#include <sig-avr.h>

#include "global.h"

// Define the debounce threshold.
// When a button is pressed, the program will increment 
// a counter in a loop until this threshold is reached.
// It is a standard way to eliminate noise from a button 
// press, to ensure the button doesn't bounce around when 
// it is initially pressed.
#define DEBOUNCE_THRESHOLD 10


void checkButtons(void) {

  //variable for reading input pins
  u08 portStatus;
  
  //counter
  u08 i;

  //array of debounce counters
  static u08 buttonDownCounter[4];

	// read the Port D pins
	portStatus = inb(PORTD);

	for (i=0; i<4; i++){            //loop for 4 buttons	  

	  if (! bit_is_set(PIND,i+4)) { //button is pressed
	    //check if DEBOUNCE_THRESHOLD has been reached
	    if (buttonDownCounter[i]++ == DEBOUNCE_THRESHOLD)
	      //light the LED
	      cbi(PORTD,i);
	  } 
	  
	  else { //button is not pressed
	    //reset debounce counter
	    buttonDownCounter[i] = 0;
	    //turn off the LED
	    sbi(PORTD,i);
	  }
	}  
}		


int main(void)
{
        // set led pins as outputs,  button pins as inputs
	outb(DDRD, 0x0F);

	// Turn off LEDs - looking at the circuit
	// you can see that they are off when pulled high
	outb(PORTD, 0xFF);
	
	// loop forever
	while(1) {

	  checkButtons();
	}

	return 0;
}

