//*************************************** 
//***************************************
//   
//  AVRLIB-DEMO
//  For avrlib and avrmini development board.
//  
//
//  File:     a2dtest.c
//  Author:   Michael Gurevich
//  Date:     Sept. 23, 2002
//  Modified: Sept: 23, 2002
//  
//
//  Using the avrmini development board, connect
//  an LCD display to the LCD header.
//  
//
//***************************************
// This program does A/D conversion and
// writes to an LCD with rprintf.
// 
//***************************************
  
#include <io.h>
#include <interrupt.h>
#include <sig-avr.h>
#include "timer.h"
#include "global.h"
#include "rprintf.h"
#include "lcd.h"
#include "a2d.h"


int main(void)
{

  u16 a2dvalue;    // variable to store a/d value

  //LCD Stuff
  lcdInit();
  rprintfInit(&lcdDataWrite);
  lcdClear();
  lcdHome();

  //Initialize timer
  timerInit();

  // ATOD STUFF
  a2dInit();
  a2dSetReference(0x01);
  
  sei();                   // enable interrupts 
  outb(DDRA, 0xF0);        // set low 4 pins of Port A to input (for ADC) 
                           // and high 4 pins to output (for LCD) 
  outb(PORTA, 0x0F);       // set pull-ups to on 
 
  while (1)  {             // loop forever 
    timerPause(100);                    // pause 
    a2dvalue = a2dConvert10bit(2);      // read the a/d on PortA pin 2
    
    lcdHome();
    rprintf("A/D Hex Value: ");
    rprintfu16(a2dvalue);
    lcdGotoXY(0,1);
    rprintf("  In Decimal:  ");
    rprintfNum(10, 4,  FALSE, ' ', a2dvalue);
     

  }
  a2dOff();
  return 0;
}
